searchData={"items":[{"type":"module","title":"SRTM","doc":"A simple interface to query locations on the Earth for elevation data from the NASA Shuttle Radar\nTopography Mission (SRTM).","ref":"SRTM.html"},{"type":"function","title":"SRTM.get_elevation/3","doc":"Queries locations on the earth for elevation data.\n\nIf the corresponding file can't be found in the cache, it will be retrieved online.\n\nReturns the elevation in meters.","ref":"SRTM.html#get_elevation/3"},{"type":"function","title":"Note - SRTM.get_elevation/3","doc":"* Make sure to match on the client to always use the latests client struct. Otherwise the SRTM\n  files will be re-read into memory on every call!\n\n* The SRTM files are cached in memory. Querying many coordinates at different locations may\n  therefore take up a lot of memory space. See `SRTM.Client.purge_in_memory_cache/2`.","ref":"SRTM.html#get_elevation/3-note"},{"type":"function","title":"Examples - SRTM.get_elevation/3","doc":"iex> {:ok, client} = SRTM.Client.new(\"./cache\")\n    iex> {:ok, elevation, client} = SRTM.get_elevation(client, 36.455556, -116.866667)\n    {:ok, -51, %SRTM.Client{}}","ref":"SRTM.html#get_elevation/3-examples"},{"type":"type","title":"SRTM.elevation/0","doc":"Elevation (in meters)","ref":"SRTM.html#t:elevation/0"},{"type":"type","title":"SRTM.latitude/0","doc":"A geographic coordinate that specifies the north–south position of a point on the surface of the\nEarth.","ref":"SRTM.html#t:latitude/0"},{"type":"type","title":"SRTM.longitude/0","doc":"A geographic coordinate that specifies the east–west position of a point on the surface of the\nEarth.","ref":"SRTM.html#t:longitude/0"},{"type":"module","title":"SRTM.Client","doc":"The client for querying elevation data.","ref":"SRTM.Client.html"},{"type":"function","title":"SRTM.Client.new/2","doc":"Creates a client struct that holds configuration and parsed HGT files.\n\nIf the directory at the given `path` doesn't exist, creates it.","ref":"SRTM.Client.html#new/2"},{"type":"function","title":"Options - SRTM.Client.new/2","doc":"The supported options are:\n\n* `:sources` (list of `t:module/0`) - the SRTM source providers (defaults to `SRTM.Source.AWS` and `SRTM.Source.ESA`)","ref":"SRTM.Client.html#new/2-options"},{"type":"function","title":"Examples - SRTM.Client.new/2","doc":"iex> {:ok, client} = SRTM.Client.new(\"./cache\")\n    {:ok, %SRTM.Client{}}","ref":"SRTM.Client.html#new/2-examples"},{"type":"function","title":"SRTM.Client.purge_in_memory_cache/2","doc":"Removes parsed HGT files from the in-memory cache.","ref":"SRTM.Client.html#purge_in_memory_cache/2"},{"type":"function","title":"Options - SRTM.Client.purge_in_memory_cache/2","doc":"The supported options are:\n\n* `:keep` - the number of most recently used HGT files to keep (default: 0)","ref":"SRTM.Client.html#purge_in_memory_cache/2-options"},{"type":"function","title":"Examples - SRTM.Client.purge_in_memory_cache/2","doc":"iex> {:ok, client} = SRTM.Client.purge_in_memory_cache(client, keep: 1)\n    {:ok, %SRTM.Client{}}","ref":"SRTM.Client.html#purge_in_memory_cache/2-examples"},{"type":"opaque","title":"SRTM.Client.t/0","doc":"","ref":"SRTM.Client.html#t:t/0"},{"type":"behaviour","title":"SRTM.Source","doc":"Specifies the API for using a custom SRTM dataset source.","ref":"SRTM.Source.html"},{"type":"callback","title":"SRTM.Source.fetch/3","doc":"Downloads the HGT file for the given coordinates and stores it under the given\n`client.cache_path`.\n\nIf successful, returns an ok tuple with the path to the file. Otherwise returns an error tuple\nwith an `SRTM.Error.t()` or `:out_of_bounds`.","ref":"SRTM.Source.html#c:fetch/3"},{"type":"type","title":"SRTM.Source.coordinates/0","doc":"","ref":"SRTM.Source.html#t:coordinates/0"},{"type":"type","title":"SRTM.Source.opts/0","doc":"","ref":"SRTM.Source.html#t:opts/0"},{"type":"module","title":"SRTM.Source.AWS","doc":"The built-in source for the [Terrain Tiles dataset](https://registry.opendata.aws/terrain-tiles/)\nhosted in Open Data Registry on AWS.","ref":"SRTM.Source.AWS.html"},{"type":"module","title":"SRTM.Source.ESA","doc":"The built-in source for the SRTMGL1 dataset hosted on\n[esa.int](http://step.esa.int/auxdata/dem/SRTMGL1/).","ref":"SRTM.Source.ESA.html"},{"type":"exception","title":"SRTM.Error","doc":"The SRTM error struct.","ref":"SRTM.Error.html"},{"type":"type","title":"SRTM.Error.t/0","doc":"","ref":"SRTM.Error.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.7.0 (2023-08-13) - Changelog","doc":"#","ref":"changelog.html#v0-7-0-2023-08-13"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Require Elixir 1.11\n- Remove USGS source\n- Drop `:adapter` and `:opts` option from `SRTM.Client.new/1`\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Changes - Changelog","doc":"- Replace hackney with httpc\n- Update documentation\n- Add CI workflow","ref":"changelog.html#changes"},{"type":"extras","title":"v0.6.0 (2020-12-02) - Changelog","doc":"#","ref":"changelog.html#v0-6-0-2020-12-02"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Use `Tesla.Adapter.Hackney` as default adapter. Add `hackney` to the list of dependencies if you don't want to use another HTTP adapter (see [Tesla Adapters](https://github.com/teamon/tesla#adapters) to find all available adapters and [`SRTM.Client.new/2`](https://hexdocs.pm/srtm/SRTM.Client.html#new/2) on how to configure another adapter).\n\n  ```elixir\n  def deps do\n    [\n      {:srtm, \"~> 0.6\"},\n      {:hackney, \"~> 1.15\"}\n    ]\n  end\n  ```","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"SRTM","doc":"# SRTM\n\n[![CI](https://github.com/adriankumpf/srtm/actions/workflows/elixir.yml/badge.svg)](https://github.com/adriankumpf/srtm/actions/workflows/elixir.yml)\n[![Docs](https://img.shields.io/badge/hex-docs-green.svg?style=flat)](https://hexdocs.pm/srtm)\n[![Hex.pm](https://img.shields.io/hexpm/v/srtm?color=%23714a94)](http://hex.pm/packages/srtm)\n\nA small library that provides a simple interface to query locations on the Earth for elevation data from the NASA Shuttle Radar Topography Mission (SRTM).","ref":"readme.html"},{"type":"extras","title":"Installation - SRTM","doc":"Add `srtm` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:srtm, \"~> 0.6\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Examples - SRTM","doc":"```elixir\n{:ok, client} = SRTM.Client.new(\"./cache\")\n#=> {:ok, %SRTM.Client{}}\n\n{:ok, elevation, client} = SRTM.get_elevation(client, 36.455556, -116.866667)\n#=> {:ok, -51, %SRTM.Client{}}\n```\n\nSee the [documentation](https://hexdocs.pm/srtm) for further information on configuration.","ref":"readme.html#examples"}],"content_type":"text/markdown"}